@@ -3,7 +3,22 @@ import socket
 
 
 class Connect:
+    """
+    The Connect class makes it easier to connect to the 2 or 4 connection CTS to get live data.
+    """
+
     def __init__(self, connections=2, data_method=None, com=None, port=None, exe_location=None):
+        """
+        Arguments:
+        - connections (int req): States if you are connecting to either a 2 or 4 connection CTS.
+        - data_method (str req): States what data retrieval method is being used. Either 'com',
+        'socket', or 'exe'.
+        - com (str): Value of COM point to connect to (ex. 'COM3'). Required if data_method is 'com'.
+        - port (int): Value of socket port to connect to (ex. 8888). Required if data_method is 'socket'.
+        - exe_location (str): Value of location to visual_backend_v1.exe
+        (ex. 'c:/Users/user/Desktop/visual_backend_v1.exe'). Required if data_method is 'exe'.
+        """
+
         self.ser = None
         self.mainSocket = None
 
@@ -33,6 +48,10 @@ class Connect:
                 raise Exception('When data_method value is exe... exe_location must have a string value.')
 
     def init(self):
+        """
+        Sets up the Connect class. A required step before running any functions.
+        """
+
         if self.data_method == 'com':
             port = "\\\\.\\" + str(self.com)
             self.ser = serial.Serial(port, 4608000, timeout=0)
@@ -41,20 +60,36 @@ class Connect:
             remote_ip = socket.gethostbyname(socket.gethostname())
             self.mainSocket.connect((remote_ip, self.port))
         elif self.data_method == 'exe':
-            return
+            return Exception("The data_method exe has not been implemented yet")
 
     def read_line(self, do_check=True):
+        """
+        Returns string of the latest data from the CTS. Returns None if no data is there.
+
+        Arguments:
+        - do_check (bool): Default is True. This value indicates if data_method is 'com' that it will check
+        if there is data to return.
+        """
+
         if self.data_method == 'com':
             if (do_check and self.size() > 30) or not do_check:
                 return self.ser.readline()
             else:
-                return
+                return None
         elif self.data_method == 'socket':
             return self.mainSocket.recv(1024)
         elif self.data_method == 'exe':
-            return
+            return Exception("The data_method exe has not been implemented yet")
 
     def get_cords(self, do_check=True):
+        """
+        Returns array of the latest data from the CTS. Returns empty array if no data is there.
+
+        Arguments:
+        - do_check (bool): Default is True. This value indicates if data_method is 'com' that it will check
+        if there is data to return.
+        """
+
         read = self.read_line(do_check)
         if read is not None:
             tmp = read.decode().split(',')
@@ -67,17 +102,34 @@ class Connect:
             return []
 
     def size(self):
+        """
+        Only if data_method is 'com' return the bytes (int) waiting in the queue.
+        """
+
         if self.data_method == 'com':
             return self.ser.inWaiting()
-        elif self.data_method == 'socket':
-            raise Exception("This function size is not available for this data_method")
-        elif self.data_method == 'exe':
+        else:
             raise Exception("This function size is not available for this data_method")
 
     def flush(self):
+        """
+        Only if data_method is 'com' flush the data waiting in queue.
+        """
+
         if self.data_method == 'com':
             self.ser.flush()
+        else:
+            raise Exception("This function flush is not available for this data_method")
+
+    def end(self):
+        """
+        End process of receiving data for cts. If any functions are run after this they will throw
+        errors.
+        """
+
+        if self.data_method == 'com':
+            self.ser.close()
         elif self.data_method == 'socket':
-            raise Exception("This function flush is not available for this data_method")
+            self.mainSocket.close()
         elif self.data_method == 'exe':
-            raise Exception("This function flush is not available for this data_method")
+            return Exception("The data_method exe has not been implemented yet")
